if [ ! -r dev/pilot ]; then # pick a default
  ( cd dev ; ln -sf ttyS0 pilot )
fi
( cd usr/lib ; rm -rf libpisock.so.8 )
( cd usr/lib ; ln -sf libpisock.so.8.0.5 libpisock.so.8 )
( cd usr/lib ; rm -rf libpisock.so )
( cd usr/lib ; ln -sf libpisock.so.8.0.5 libpisock.so )
( cd usr/lib ; rm -rf libpisync.so.0 )
( cd usr/lib ; ln -sf libpisync.so.0.0.1 libpisync.so.0 )
( cd usr/lib ; rm -rf libpisync.so )
( cd usr/lib ; ln -sf libpisync.so.0.0.1 libpisync.so )
( cd usr/lib ; rm -rf libpisock++.so.0 )
( cd usr/lib ; ln -sf libpisock++.so.0.0.0 libpisock++.so.0 )
( cd usr/lib ; rm -rf libpisock++.so )
( cd usr/lib ; ln -sf libpisock++.so.0.0.0 libpisock++.so )
